## CHANGELOG

### 0.5.0 - 2020-07-07

 - Refactor api

### 0.4.0 - 2020-07-06

 - Create docs

 - Fix api publish and listen methods

### 0.3.1 - 2020-07-03

 - Support load subscriber as script

### 0.3.0 - 2020-07-03

 - Create subscriber cli

### 0.2.0 - 2020-07-02

 - Create publish and listen methods for api

###  - 2020-07-02

 - Create Api object from asyncapi spec
